@@ -1,2 +1,5 @@
 pub mod error;
 pub mod hybrid_gpsw_aes;
+
+#[cfg(test)]
+mod tests;
